@@ -31,11 +31,12 @@ import traceback
 
 import pyatspi
 
-import braille
-import debug
-import settings
+from . import braille
+from . import debug
+from . import settings
 
-from orca_i18n import _         # for gettext support
+from .orca_i18n import _         # for gettext support
+import collections
 
 def _formatExceptionInfo(maxTBlevel=5):
     cla, exc, trbk = sys.exc_info()
@@ -71,10 +72,7 @@ class Generator:
         self._script = script
         self._methodsDict = {}
         for method in \
-            filter(lambda z: callable(z),
-                   map(lambda y: getattr(self, y).__get__(self, self.__class__),
-                       filter(lambda x: x.startswith(METHOD_PREFIX),
-                                        dir(self)))):
+            [z for z in [getattr(self, y).__get__(self, self.__class__) for y in [x for x in dir(self) if x.startswith(METHOD_PREFIX)]] if isinstance(z, collections.Callable)]:
             name = method.__name__[len(METHOD_PREFIX):]
             name = name[0].lower() + name[1:]
             self._methodsDict[name] = method
@@ -97,7 +95,7 @@ class Generator:
         # for the results of all the legal method names.
         #
         globalsDict = {}
-        for key in self._methodsDict.keys():
+        for key in list(self._methodsDict.keys()):
             globalsDict[key] = []
         self._addGlobals(globalsDict)
 
@@ -122,7 +120,7 @@ class Generator:
                             arg = info[1][0]
                             arg = arg.replace("name '", "")
                             arg = arg.replace("' is not defined", "")
-                            if not self._methodsDict.has_key(arg):
+                            if arg not in self._methodsDict:
                                 debug.printException(debug.LEVEL_SEVERE)
                                 debug.println(
                                     debug.LEVEL_SEVERE,
@@ -183,8 +181,12 @@ class Generator:
         globalsDict = {}
         self._addGlobals(globalsDict)
         globalsDict['obj'] = obj
-        globalsDict['role'] = args.get('role', obj.getRole())
-
+        try:
+            globalsDict['role'] = args.get('role', obj.getRole())
+        except:
+            msg = 'Cannot generate presentation for: %s. Aborting' % obj
+            debug.println(debug.LEVEL_FINEST, msg)
+            return result
         try:
             # We sometimes want to override the role.  We'll keep the
             # role in the args dictionary as a means to let us do so.
@@ -244,7 +246,7 @@ class Generator:
                     arg = info[1][0]
                     arg = arg.replace("name '", "")
                     arg = arg.replace("' is not defined", "")
-                    if not self._methodsDict.has_key(arg):
+                    if arg not in self._methodsDict:
                         debug.printException(debug.LEVEL_SEVERE)
                         debug.println(
                             debug.LEVEL_SEVERE,
@@ -326,10 +328,8 @@ class Generator:
         the assumption being that the user was able to see the text prior
         to giving the widget focus.
         """
-        result = filter(lambda x:
-                        x.startswith('placeholder-text:'),
-                        obj.getAttributes())
-        return map(lambda x: x.replace('placeholder-text:', ''), result)
+        result = [x for x in obj.getAttributes() if x.startswith('placeholder-text:')]
+        return [x.replace('placeholder-text:', '') for x in result]
 
     def _generateLabelAndName(self, obj, **args):
         """Returns the label and the name as an array of strings for speech
@@ -598,7 +598,10 @@ class Generator:
             pass
         else:
             index = self._script.utilities.cellIndex(obj)
-            rowIndex = table.getRowAtIndex(index)
+            try:
+                rowIndex = table.getRowAtIndex(index)
+            except:
+                rowIndex = -1
             if rowIndex >= 0:
                 # Get the header information.  In Java Swing, the
                 # information is not exposed via the description
@@ -641,7 +644,10 @@ class Generator:
 
         # Do not return yourself as a header.
         #
-        role = args.get('role', obj.getRole())
+        try:
+            role = args.get('role', obj.getRole())
+        except:
+            role = None
         if role in [pyatspi.ROLE_COLUMN_HEADER,
                     pyatspi.ROLE_TABLE_COLUMN_HEADER]:
             return result
@@ -986,7 +992,11 @@ class Generator:
         empty array if the object has no such label.
         """
         result = []
-        if obj.getRole() == pyatspi.ROLE_RADIO_BUTTON:
+        try:
+            role = obj.getRole()
+        except:
+            role = None
+        if role == pyatspi.ROLE_RADIO_BUTTON:
             radioGroupLabel = None
             relations = obj.getRelationSet()
             for relation in relations:
