@@ -28,11 +28,11 @@ __license__   = "LGPL"
 
 # $ORCA_MAJOR_VERSION.$ORCA_MINOR_VERSION.$ORCA_MICRO_VERSION
 #
-version     = "3.5.5"
+version     = "3.5.90"
 
 # "--prefix" parameter used when configuring the build.
 #
-prefix      = "/home/jd/checkout/gnome/orca/bld"
+prefix      = "/home/jd/orca/bld"
 
 # The package name (should be "orca").
 #
